@@ -2,6 +2,7 @@
 """
 import json
 from enum import Enum
+from inspect import signature
 from typing import Dict, List, Optional
 
 import requests
@@ -29,6 +30,7 @@ class CodeOceanClient:
         BUCKET = "bucket"
         CAPSULE_ID = "capsule_id"
         COMPUTATION = "computation"
+        CUSTOM_METADATA = "custom_metadata"
         DATA_ASSETS = "data_assets"
         DESCRIPTION = "description"
         EVERYONE = "everyone"
@@ -137,12 +139,16 @@ class CodeOceanClient:
         ---------------
         requests.models.Response
         """
-        optional_params = locals()
-        query_params = {}
-
-        for param, val in optional_params.items():
-            if val is not None:
-                query_params[param] = val
+        frame_locals = locals()
+        query_params = dict(
+            [
+                (k, frame_locals[k])
+                for k, v in signature(
+                    self.search_data_assets
+                ).parameters.items()
+                if frame_locals[k] is not None
+            ]
+        )
 
         response = requests.get(
             self.asset_url, params=query_params, auth=(self.token, "")
@@ -187,12 +193,16 @@ class CodeOceanClient:
 
         # TODO: it'd be nice to re-use the search_data_assets function, but
         #  it'll require passing in a requests.Session object into that method.
-        optional_params = locals()
-        query_params = {}
-
-        for param, val in optional_params.items():
-            if val is not None:
-                query_params[param] = val
+        frame_locals = locals()
+        query_params = dict(
+            [
+                (k, frame_locals[k])
+                for k, v in signature(
+                    self.search_all_data_assets
+                ).parameters.items()
+                if frame_locals[k] is not None
+            ]
+        )
 
         requests_session = requests.Session()
         all_results = []
@@ -239,6 +249,7 @@ class CodeOceanClient:
         asset_description: Optional[str] = "",
         keep_on_external_storage: Optional[bool] = True,
         index_data: Optional[bool] = True,
+        custom_metadata: Optional[dict] = None,
     ) -> requests.models.Response:
         """
         Parameters
@@ -266,6 +277,8 @@ class CodeOceanClient:
             Keep data asset on external storage. Defaults to True.
         index_data : Optional[bool]
             Whether to index the data asset. Defaults to True.
+        custom_metadata : Optional[dict]
+            What key:value metadata tags to apply to the asset.
         Returns
         ---------------
         requests.models.Response
@@ -287,6 +300,7 @@ class CodeOceanClient:
                     self._Fields.INDEX_DATA.value: index_data,
                 }
             },
+            self._Fields.CUSTOM_METADATA.value: custom_metadata,
         }
 
         if access_key_id and secret_access_key:
@@ -309,6 +323,7 @@ class CodeOceanClient:
         asset_description: Optional[str] = "",
         mount: Optional[str] = None,
         tags: Optional[List] = None,
+        custom_metadata: Optional[dict] = None,
     ) -> requests.models.Response:
         """
         Parameters
@@ -324,11 +339,12 @@ class CodeOceanClient:
         tags : Optional[List[str]]
             A list of tags to attach to the data asset.
             Default None (empty list).
-
         keep_on_external_storage : Optional[bool]
             Keep data asset on external storage. Defaults to True.
         index_data : Optional[bool]
             Whether to index the data asset. Defaults to True.
+        custom_metadata : Optional[dict]
+            What key:value metadata tags to apply to the asset.
         Returns
         ---------------
         requests.models.Response
@@ -349,6 +365,7 @@ class CodeOceanClient:
                     self._Fields.ID.value: computation_id
                 }
             },
+            self._Fields.CUSTOM_METADATA.value: custom_metadata,
         }
 
         response = requests.post(
@@ -364,6 +381,7 @@ class CodeOceanClient:
         new_description: Optional[str] = None,
         new_tags: Optional[List[str]] = None,
         new_mount: Optional[str] = None,
+        new_custom_metadata: Optional[dict] = None,
     ) -> requests.models.Response:
         """
         This will update a data asset from a PUT request to Code Ocean API.
@@ -380,6 +398,9 @@ class CodeOceanClient:
             New tags of the data asset. Default None (not updated)
         new_mount : str
             New mount of the data asset. Default None (not updated)
+        new_custom_metadata : Optional[dict]
+            What key:value metadata tags to apply to the asset.
+
         Returns
         ---------------
         requests.models.Response
@@ -397,6 +418,9 @@ class CodeOceanClient:
         if new_mount:
             data[self._Fields.MOUNT.value] = new_mount
 
+        if new_custom_metadata:
+            data[self._Fields.CUSTOM_METADATA.value] = new_custom_metadata
+
         response = requests.put(url, json=data, auth=(self.token, ""))
 
         return response
@@ -434,6 +458,7 @@ class CodeOceanClient:
             ]
             where position one refers to the parameter #1 ('input_folder'),
             parameter #2 ('output_folder'), and parameter #3 ('bucket_name')
+
         Returns
         ---------------
         requests.models.Response
