@@ -3,6 +3,7 @@ import json
 import unittest
 from typing import Any, Callable, List
 from unittest import mock
+from unittest.mock import call
 
 import requests
 
@@ -102,6 +103,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
                     "secret_access_key": secret_access_key,
                 }
             },
+            "custom_metadata": None,
         }
 
         def map_to_success_message(input_json: dict) -> dict:
@@ -229,7 +231,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
         )
 
         example_data_asset_id = "6260cf28-de91-4528-9286-9c09869e00ec"
-        example_query = "ecephys"
+        example_query = "tag:ecephys"
         example_favorite = True
         example_archived = True
 
@@ -256,6 +258,15 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
             "type": "dataset",
         }
 
+        mock_api_get.assert_called_once_with(
+            "https://acmecorp.codeocean.com/api/v1/data_assets",
+            params={
+                "favorite": True,
+                "archived": True,
+                "query": "tag:ecephys",
+            },
+            auth=("CODEOCEAN_API_TOKEN", ""),
+        )
         self.assertEqual(response.content, expected_response)
         self.assertEqual(response.status_code, 200)
 
@@ -313,6 +324,25 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
         response_bad = self.co_client.search_all_data_assets(archived=False)
         actual_bad_response = response_bad.json()
 
+        mock_api_get.assert_has_calls(
+            [
+                call(
+                    "https://acmecorp.codeocean.com/api/v1/data_assets",
+                    params={"start": 2, "limit": 1000},
+                    auth=("CODEOCEAN_API_TOKEN", ""),
+                ),
+                call(
+                    "https://acmecorp.codeocean.com/api/v1/data_assets",
+                    params={"start": 2, "limit": 1000},
+                    auth=("CODEOCEAN_API_TOKEN", ""),
+                ),
+                call(
+                    "https://acmecorp.codeocean.com/api/v1/data_assets",
+                    params={"archived": False, "start": 0, "limit": 1000},
+                    auth=("CODEOCEAN_API_TOKEN", ""),
+                ),
+            ]
+        )
         self.assertEqual(200, response.status_code)
         self.assertEqual(expected_response, actual_response)
         self.assertEqual(500, response_bad.status_code)
@@ -346,6 +376,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
             "name": "modified name",
             "description": "a new description",
             "tags": ["aaa", "bbb"],
+            "custom_metadata": {"key": "value"},
             "mount": "newmount",
         }
         mocked_success_put = self.mock_success_response(
@@ -362,6 +393,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
             new_description="a new description",
             new_tags=["aaa", "bbb"],
             new_mount="newmount",
+            new_custom_metadata={"key": "value"},
         )
 
         expected_response = {
@@ -666,6 +698,7 @@ class TestCodeOceanDataAssetRequests(unittest.TestCase):
             "description": "",
             "mount": mount,
             "tags": [],
+            "custom_metadata": None,
             "source": {
                 "computation": {"id": "44ec16c3-cb5a-4000-93d1-cba8be800c00"}
             },
